/* xdwapi sample 6

Function :
  Automatically rotates each page of DocuWorks document and performs OCR.
How to use :
  xdwsmpl6 document

  document : DocuWorks document (in).

  The default operation of OCR is performed.
*/

#include <stdio.h>
#include <windows.h>

#include <xdw_api.h>

void print_error(int code)
{
	switch (code) {
	case XDW_E_NOT_INSTALLED:
		fprintf(stderr, "DocuWorks not installed.");
		break;
	case XDW_E_FILE_NOT_FOUND:
		fprintf(stderr, "File not found.");
		break;
	case XDW_E_ACCESSDENIED:
	case XDW_E_INVALID_NAME:
	case XDW_E_BAD_NETPATH:
		fprintf(stderr, "File not opened.");
		break;
	case XDW_E_BAD_FORMAT:
		fprintf(stderr, "File bad format.");
		break;
	case XDW_E_INVALID_ACCESS:
		fprintf(stderr, "Invalid access.");
		break;
	case XDW_E_CANCELED:
		fprintf(stderr, "Canceled.");
		break;
	default:
		fprintf(stderr, "Error. codeF0x%X", code);
		break;
	}
}

int main(int argc, char** argv)
{
	int api_result = 0;

	if (argc != 2) {
		fprintf(stderr, "How to use : xdwsmpl6 document");
		return 0;
	}

	char in_path[_MAX_PATH];
	_fullpath(in_path, argv[1], _MAX_PATH);

	// Open the document handle.
	XDW_DOCUMENT_HANDLE h = NULL;
	XDW_OPEN_MODE_EX mode = {
		sizeof(XDW_OPEN_MODE_EX), XDW_OPEN_UPDATE, XDW_AUTH_NODIALOGUE };
	api_result = XDW_OpenDocumentHandle(in_path, &h, (XDW_OPEN_MODE*)&mode);
	if (api_result < 0) {
		print_error(api_result);
		return 0;
	}

	// Use XDW_GetDocumentInformation to get the number of total pages.
	XDW_DOCUMENT_INFO info = { sizeof(XDW_DOCUMENT_INFO), 0 };
	XDW_GetDocumentInformation(h, &info);
	int last_page = info.nPages;

	// Automatically rotate each page and perform OCR.
	int is_modified = 0;
	for (int i = 1; i <= last_page; i++) {
		api_result = XDW_RotatePageAuto(h, i, NULL);
		if (api_result >= 0) {
			is_modified = 1;
		}
		api_result = XDW_ApplyOcr(h, i, XDW_OCR_ENGINE_V4, NULL, NULL);
		if (api_result >= 0) {
			is_modified = 1;
		}
		if (api_result == XDW_E_CANCELED) {
			print_error(api_result);
			break;
		}
	}

	// Reflect the changes to the document.
	if (is_modified) {
		api_result = XDW_SaveDocument(h, NULL);
	}

	// Close the document handle.
	XDW_CloseDocumentHandle(h, NULL);

	// Terminate the process of XDW_ApplyOcr.
	XDW_Finalize(NULL);

	if (api_result < 0) return 0;

	return 1;
}
