/* xdwapi sample

Function :
  Creates DocuWorks document from an image file.
How to use :
  xdwsmpl image [document]

  image : BMP, JPEG or TIFF format file (in).
  document : DocuWorks document (out).
  if document is omitted, DocuWorks Desk is started and the document is created there.
*/

using System;
using System.Collections.Generic;
using System.Text;
using System.IO;
using System.Diagnostics;
using FujiXerox.DocuWorks.Toolkit;

namespace XdwSmpl
{
    class Program
    {
        static int Main(string[] args)
        {
            int api_result = 0;

            if (args.Length != 2 && args.Length != 1) {
                TextWriter errorWriter = Console.Error;
                errorWriter.WriteLine("How to use: xdwsmpl image [document]");
                return 0;
            }

            string in_path = Path.GetFullPath(args[0]);
            
            string out_path = null;
            if (args.Length == 2) {
                out_path = Path.GetFullPath(args[1]);
            } else {
                // Use XDW_GetInformation to get the directory for inputting DocuWorks documents.
                // Create DocuWorks document in the directory.
                // After DocuWorks Desk starts, the document presents.
                api_result = Xdwapi.XDW_GetInformation(Xdwapi.XDW_GI_DWINPUTPATH, ref out_path);
                if (api_result < 0) {
                    print_error(api_result);
                    return 0;
                }
                string fname = Path.GetFileNameWithoutExtension(in_path);
                out_path += "\\";
                out_path += fname;
                out_path += ".xdw";
            }

            // Use XDW_CreateXdwFromImageFile to create DocuWorks document from the image file.
            // Set nFitImage up as 1 to set the page size to be the same as the image size.
            Xdwapi.XDW_CREATE_OPTION_EX2 option = new Xdwapi.XDW_CREATE_OPTION_EX2();
            option.FitImage = Xdwapi.XDW_CREATE_FIT;

            api_result = Xdwapi.XDW_CreateXdwFromImageFile(in_path, out_path, option);
            if (api_result < 0) {
                print_error(api_result);
                return 0;
            }

            if (args.Length == 2) {
                // Use XDW_GetInformation to get DocuWorks Desk program path.
                string desk_path = null;
                api_result = Xdwapi.XDW_GetInformation(Xdwapi.XDW_GI_DWDESKPATH, ref desk_path);
                if (api_result < 0) {
                    print_error(api_result);
                    return 0;
                }

                Process.Start(desk_path);
            }

            return 1;
        }

        static void print_error(int code)
        {
            TextWriter errorWriter = Console.Error;
            switch (code)
            {
                case Xdwapi.XDW_E_NOT_INSTALLED:
                    errorWriter.WriteLine("DocuWorks not installed.");
                    break;
                case Xdwapi.XDW_E_FILE_NOT_FOUND:
                    errorWriter.WriteLine("File not found.");
                    break;
                case Xdwapi.XDW_E_FILE_EXISTS:
                    errorWriter.WriteLine("File exists.");
                    break;
                case Xdwapi.XDW_E_ACCESSDENIED:
                case Xdwapi.XDW_E_INVALID_ACCESS:
                case Xdwapi.XDW_E_INVALID_NAME:
                case Xdwapi.XDW_E_BAD_NETPATH:
                    errorWriter.WriteLine("File not opened.");
                    break;
                case Xdwapi.XDW_E_BAD_FORMAT:
                    errorWriter.WriteLine("File bad format.");
                    break;
                default:
                    errorWriter.WriteLine("Error.");
                    break;
            }
        }
    }
}
