/* xdwapi sample 10

Function :
  Gets information about the LinkRoot folder on the DocuWorks Desk.
How to use :
  xdwsmpl10
*/

using System;
using System.Collections.Generic;
using System.Text;
using System.IO;
using FujiXerox.DocuWorks.Toolkit;

namespace XdwSmpl10
{
    class Program
    {
        static int Main(string[] args)
        {
            int api_result = 0;

            if (args.Length != 0)
            {
                TextWriter errorWriter = Console.Error;
                errorWriter.WriteLine("How to use : xdwsmpl10");
                return 0;
            }

            // Get the number of LinkRoot folders in a Link folder on the DocuWorks Desk.
            int folder_num = Xdwapi.XDW_GetLinkRootFolderNumber();
            if (folder_num < 0)
            {
                print_error(folder_num);
                return 0;
            }
            else if (folder_num == 0)
            {
                Console.WriteLine(" No LinkRoot folders.");
                return 1;
            }
            else
            {
                Xdwapi.XDW_LINKROOTFOLDER_INFO info = new Xdwapi.XDW_LINKROOTFOLDER_INFO();
                for (int i = 1; i <= folder_num; i++)
                {
                    api_result = Xdwapi.XDW_GetLinkRootFolderInformation(i, ref info);
                    if (api_result < 0)
                    {
                        print_error(api_result);
                        break;
                    }
                    Console.WriteLine(" LinkRoot folder {0} : Path {1},  Name {2}", i, info.Path, info.LinkRootFolderName);
                }
            }

            if (api_result < 0)
                return 0;

            return 1;
        }
        
        static void print_error(int code)
        {
            TextWriter errorWriter = Console.Error;
            switch (code)
            {
                case Xdwapi.XDW_E_NOT_INSTALLED:
                    errorWriter.WriteLine("DocuWorks not installed.");
                    break;
                case Xdwapi.XDW_E_FILE_NOT_FOUND:
                    errorWriter.WriteLine("File not found.");
                    break;
                case Xdwapi.XDW_E_ACCESSDENIED:
                case Xdwapi.XDW_E_INVALID_NAME:
                case Xdwapi.XDW_E_BAD_NETPATH:
                    errorWriter.WriteLine("File not opened.");
                    break;
                case Xdwapi.XDW_E_BAD_FORMAT:
                    errorWriter.WriteLine("File bad format.");
                    break;
                case Xdwapi.XDW_E_INVALID_ACCESS:
                    errorWriter.WriteLine("Invalid access.");
                    break;
                default:
                    errorWriter.WriteLine("Error.");
                    break;
            }
        }
    }
}
