/* xdwapi sample 2

Function :
  Gets the text data of a page at the standard output.
How to use :
  xdwsmpl2 document [page]

  document : DocuWorks document (in).
  page : Specified page (in). If omitted, all of pages are covered.
*/

using System;
using System.Collections.Generic;
using System.Text;
using System.IO;
using FujiXerox.DocuWorks.Toolkit;

namespace XdwSmpl2
{
    class Program
    {
        static int Main(string[] args)
        {
            int api_result = 0;

            if (args.Length != 2 && args.Length != 1) {
                TextWriter errorWriter = Console.Error;
                errorWriter.WriteLine("How to use : xdwsmpl2 document [page]");
                return 0;
            }

            string in_path = Path.GetFullPath(args[0]);

            int page = 0;
            if (args.Length == 2) {
                page = int.Parse(args[1]);
            }

            // Open the document handle.
            Xdwapi.XDW_DOCUMENT_HANDLE handle = new Xdwapi.XDW_DOCUMENT_HANDLE();
            Xdwapi.XDW_OPEN_MODE_EX mode = new Xdwapi.XDW_OPEN_MODE_EX();
            mode.Option = Xdwapi.XDW_OPEN_READONLY;
            mode.AuthMode = Xdwapi.XDW_AUTH_NODIALOGUE;
            api_result = Xdwapi.XDW_OpenDocumentHandle(in_path, ref handle, mode);
            if (api_result < 0) {
                print_error(api_result);
                return 0;
            }

            // Use XDW_GetDocumentInformation to get the number of total pages.
            Xdwapi.XDW_DOCUMENT_INFO info = new Xdwapi.XDW_DOCUMENT_INFO();
            Xdwapi.XDW_GetDocumentInformation(handle, ref info);
            int last_page = info.Pages;

            if (args.Length == 2) {
                if (page < 1 || page > last_page) {
                    TextWriter errorWriter = Console.Error;
                    errorWriter.WriteLine("Page not exist.");
                } else {
                    api_result = print_text(handle, page);
                }
            } else if (page == 0) {
                for (int i = 1; i <= last_page; i++) {
                    api_result = print_text(handle, i);
                    if (api_result < 0)
                        break;
                }
            }
            if (api_result < 0)
                print_error(api_result);

            // Close the document handle.
            Xdwapi.XDW_CloseDocumentHandle(handle);

            if (api_result >= 0)
                return 1;

            return 0;
        }

        static int print_text(Xdwapi.XDW_DOCUMENT_HANDLE handle, int page)
        {
            // Use XDW_GetPageInformation to check the page type.
            Xdwapi.XDW_PAGE_INFO_EX info = new Xdwapi.XDW_PAGE_INFO_EX();
            int result = Xdwapi.XDW_GetPageInformation(handle, page, ref info);
            if (result < 0)
                return result;

            if (info.PageType == Xdwapi.XDW_PGT_FROMAPPL || info.PageType == Xdwapi.XDW_PGT_FROMIMAGE) {
                // Use XDW_GetPageText to get text data.
                string temp_path = Path.GetRandomFileName();
                result = Xdwapi.XDW_GetPageText(handle, page, temp_path);
                if (result < 0)
                    return result;
                Console.WriteLine(File.ReadAllText(temp_path, Encoding.Default));
                File.Delete(temp_path);
            }
            return result;
        }

        static void print_error(int code)
        {
            TextWriter errorWriter = Console.Error;
            switch (code)
            {
                case Xdwapi.XDW_E_NOT_INSTALLED:
                    errorWriter.WriteLine("DocuWorks not installed.");
                    break;
                case Xdwapi.XDW_E_FILE_NOT_FOUND:
                    errorWriter.WriteLine("File not found.");
                    break;
                case Xdwapi.XDW_E_FILE_EXISTS:
                    errorWriter.WriteLine("File exists.");
                    break;
                case Xdwapi.XDW_E_ACCESSDENIED:
                case Xdwapi.XDW_E_INVALID_NAME:
                case Xdwapi.XDW_E_BAD_NETPATH:
                    errorWriter.WriteLine("File not opened.");
                    break;
                case Xdwapi.XDW_E_BAD_FORMAT:
                    errorWriter.WriteLine("File bad format.");
                    break;
                case Xdwapi.XDW_E_INVALID_ACCESS:
                    errorWriter.WriteLine("Invalid access.");
                    break;
                default:
                    errorWriter.WriteLine("Error.");
                    break;
            }
        }

    }
}
